'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.default = setMediaQueries;
function setMediaQueries(mediaQueries) {
	var mediaQueriesStore = validateMediaQueries(mediaQueries);
	var cachedMediaQuery = setMediaQuery(mediaQueriesStore);

	window.addEventListener('resize', function () {
		return cachedMediaQuery = setMediaQuery(mediaQueriesStore);
	});
	return function () {
		return cachedMediaQuery;
	};
}

function validateMediaQueries(mediaQueries) {
	var zeroMediaQueryFound = false;
	var defaultMediaQueries = {
		xxs: 0,
		xs: 320,
		s: 480,
		m: 768,
		l: 1024,
		xl: 1224,
		xxl: 1824
	};
	var defaultMediaQueriesMessage = 'Defaulting to: ' + JSON.stringify(defaultMediaQueries);

	var errors = !mediaQueries || Object.keys(mediaQueries).some(function (mediaQuery) {
		if (typeof mediaQueries[mediaQuery] !== 'number') {
			console.error('Media queries provided should be integers', defaultMediaQueriesMessage);
			return true;
		}

		if (_typeof(mediaQueries[mediaQuery]) < 0) {
			console.error('Media queries provided should be larger than 0', defaultMediaQueriesMessage);
			return true;
		}

		zeroMediaQueryFound = zeroMediaQueryFound || mediaQueries[mediaQuery] === 0;
		return false;
	});

	if (mediaQueries && !zeroMediaQueryFound) {
		console.error('A key should be for 0px break point', defaultMediaQueriesMessage);
		errors = true;
	}

	return errors ? defaultMediaQueries : mediaQueries;
}

function setMediaQuery(mediaQueriesStore) {
	var mediaQuery = Object.keys(mediaQueriesStore).sort(function (mediaQuery1, mediaQuery2) {
		return mediaQueriesStore[mediaQuery1] > mediaQueriesStore[mediaQuery2] ? -1 : 1;
	}).find(function (mediaQuery) {
		return window.matchMedia('(min-width: ' + mediaQueriesStore[mediaQuery] + 'px)').matches;
	});

	return mediaQuery;
}